OpenCensus Shim for OpenTelemetry
==================================

|pypi|

.. |pypi| image:: https://badge.fury.io/py/opentelemetry-opencensus-shim.svg
   :target: https://pypi.org/project/opentelemetry-opencensus-shim/

Installation
------------

::

    pip install opentelemetry-opencensus-shim

References
----------

* `OpenCensus Shim for OpenTelemetry <https://opentelemetry-python.readthedocs.io/en/latest/shim/opencensus_shim/opencensus_shim.html>`_
* `OpenTelemetry Project <https://opentelemetry.io/>`_
